/*******************************************************************************
* File Name: PWM_1_PM.c
* Version 1.50
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "PWM_1.h"

static PWM_1_backupStruct PWM_1_backup;


/*******************************************************************************
* Function Name: PWM_1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_1_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PWM_1_SaveConfig(void)
{
        #if(!PWM_1_UsingFixedFunction)
        
            #if(!PWM_1_PWMModeIsCenterAligned)
                PWM_1_backup.periodValue = PWM_1_ReadPeriod();
            #endif
            
            #if(PWM_1_DeadBand2_4)
                PWM_1_backup.deadBandValue = PWM_1_ReadDeadTime();
            #endif
          
            PWM_1_backup.counterValue = PWM_1_ReadCounter();           
            
            #if(PWM_1_UseControl)
                PWM_1_backup.control = PWM_1_ReadControlRegister();
            #endif 
            
        #endif
     
}


/*******************************************************************************
* Function Name: PWM_1_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_1_backup:  Variables of this global structure are used to restore 
*  the values of non retention registers on wakeup from sleep mode.
*
* Reentrant:
*  Yes.
*
*******************************************************************************/
void PWM_1_RestoreConfig(void) 
{
        #if(!PWM_1_UsingFixedFunction)
        
            #if(!PWM_1_PWMModeIsCenterAligned)
                PWM_1_WritePeriod(PWM_1_backup.periodValue);
            #endif
            
            #if(PWM_1_DeadBand2_4)
                PWM_1_WriteDeadTime(PWM_1_backup.deadBandValue);
            #endif
            
            #if(PWM_1_UseControl)
                PWM_1_WriteControlRegister(PWM_1_backup.control);
            #endif
            
            PWM_1_WriteCounter(PWM_1_backup.counterValue);          
            
        #endif
}


/*******************************************************************************
* Function Name: PWM_1_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_1_backup.pwmEnable:  Is modified depending on the enable state
*  of the block before entering sleep mode.
*
* Reentrant:
*  No.
*
*******************************************************************************/
void PWM_1_Sleep(void)
{
    #if(PWM_1_UseControl ||PWM_1_UsingFixedFunction)
        if(PWM_1_CTRL_ENABLE == (PWM_1_CONTROL & PWM_1_CTRL_ENABLE))
        {
            /*Component is enabled */
            PWM_1_backup.pwmEnable = 1u;
        }
        else
        {
            /* Component is disabled */
            PWM_1_backup.pwmEnable = 0u;
        }
    #endif
    /* Stop component */
    PWM_1_Stop();
    
    /* Save registers configuration */
    PWM_1_SaveConfig();
}


/*******************************************************************************
* Function Name: PWM_1_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  PWM_1_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
* Reentrant:
*  Yes
*
*******************************************************************************/
void PWM_1_Wakeup(void) 
{
     /* Restore registers values */
    PWM_1_RestoreConfig();
    
    if(PWM_1_backup.pwmEnable != 0u)
    {
        /* Enable component's operation */
        PWM_1_Enable();
    } /* Do nothing if component's block was disabled before */
    
}

/* [] END OF FILE */
