/*******************************************************************************
* File Name: Debounce.h  
* Version 1.50
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_PWM_Debounce_H)
#define CY_PWM_Debounce_H


/***************************************
* Conditional Compilation Parameters
***************************************/
#define Debounce_Resolution 8
#define Debounce_UsingFixedFunction 0
#define Debounce_DeadBandMode 0
#define Debounce_KillModeMinTime 0
#define Debounce_KillMode 0
#define Debounce_PWMMode 0
#define Debounce_PWMModeIsCenterAligned 0
#define Debounce_DeadBandUsed 0
#define Debounce_DeadBand2_4 0
#if !defined(Debounce_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define Debounce_UseStatus 1
#else
    #define Debounce_UseStatus 0
#endif
#if !defined(Debounce_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define Debounce_UseControl 1
#else
    #define Debounce_UseControl 0
#endif
#define Debounce_UseOneCompareMode 1
#define Debounce_MinimumKillTime 1
#define Debounce_EnableMode 0

#define Debounce_CompareMode1SW 0
#define Debounce_CompareMode2SW 0

/* PSoC3 ES2 or early */
#define Debounce_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))

/* PSoC5 ES1 or early */
#define Debounce_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))

/* PSoC3 ES3 or later */
#define Debounce_PSOC3_ES3   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                     (CYDEV_CHIP_REVISION_USED >= CYDEV_CHIP_REVISION_3A_ES3))

/* PSoC5 ES2 or later */
#define Debounce_PSOC5_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)   && \
                                     (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))

/* Use Kill Mode Enumerated Types */
#define Debounce__B_PWM__DISABLED 0
#define Debounce__B_PWM__ASYNCHRONOUS 1
#define Debounce__B_PWM__SINGLECYCLE 2
#define Debounce__B_PWM__LATCHED 3
#define Debounce__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define Debounce__B_PWM__DBMDISABLED 0
#define Debounce__B_PWM__DBM_2_4_CLOCKS 1
#define Debounce__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define Debounce__B_PWM__ONE_OUTPUT 0
#define Debounce__B_PWM__TWO_OUTPUTS 1
#define Debounce__B_PWM__DUAL_EDGE 2
#define Debounce__B_PWM__CENTER_ALIGN 3
#define Debounce__B_PWM__DITHER 5
#define Debounce__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define Debounce__B_PWM__LESS_THAN 1
#define Debounce__B_PWM__LESS_THAN_OR_EQUAL 2
#define Debounce__B_PWM__GREATER_THAN 3
#define Debounce__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define Debounce__B_PWM__EQUAL 0
#define Debounce__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/

/* Sleep Mode API Support */

typedef struct Debounce_backupStruct{
    uint8 pwmEnable;
       
    #if(!Debounce_UsingFixedFunction)
        #if(Debounce_UseControl)
            uint8 control;
        #endif
        
        #if(!Debounce_PWMModeIsCenterAligned)
            uint16 periodValue;
        #endif
        
        #if(Debounce_DeadBand2_4)
            uint8 deadBandValue;
        #endif
        
        uint8 counterValue;
        uint8 captureValue;
            
    #endif /*End of `#if(!Debounce_UsingFixedFunction)*/
   
}Debounce_backupStruct;



/***************************************
*        Function Prototypes
 **************************************/
 
void    Debounce_Start(void);
void    Debounce_Stop(void) ;
#if (Debounce_UseStatus || Debounce_UsingFixedFunction)
    #define Debounce_SetInterruptMode(interruptMode) CY_SET_REG8(Debounce_STATUS_MASK_PTR, interruptMode)
    #define Debounce_ReadStatusRegister() CY_GET_REG8(Debounce_STATUS_PTR)
#endif
#define Debounce_GetInterruptSource() Debounce_ReadStatusRegister()
#if (Debounce_UseControl)
    #define Debounce_ReadControlRegister() CY_GET_REG8(Debounce_CONTROL_PTR) 
    #define Debounce_WriteControlRegister(control) CY_SET_REG8(Debounce_CONTROL_PTR, control)
#endif
#if (Debounce_UseOneCompareMode)
   #if (Debounce_CompareMode1SW)
       void    Debounce_SetCompareMode(uint8 comparemode) ;
   #endif
#else
    #if (Debounce_CompareMode1SW)
        void    Debounce_SetCompareMode1(uint8 comparemode) ;
    #endif
    #if (Debounce_CompareMode2SW)
        void    Debounce_SetCompareMode2(uint8 comparemode) ;
    #endif
#endif

#if (!Debounce_UsingFixedFunction)
    uint8   Debounce_ReadCounter(void) ;
    #define Debounce_ReadCapture() CY_GET_REG8(Debounce_CAPTURE_LSB_PTR)
    #if (Debounce_UseStatus)
        void Debounce_ClearFIFO(void) ;
    #endif
#endif

void    Debounce_WriteCounter(uint8 counter) ;
void    Debounce_WritePeriod(uint8 period) ;
#define Debounce_ReadPeriod() CY_GET_REG8(Debounce_PERIOD_LSB_PTR) 
#if (Debounce_UseOneCompareMode)
    void    Debounce_WriteCompare(uint8 compare) ;
    #define Debounce_ReadCompare() CY_GET_REG8(Debounce_COMPARE1_LSB_PTR) 
#else
    void    Debounce_WriteCompare1(uint8 compare) ;
    #define Debounce_ReadCompare1() CY_GET_REG8(Debounce_COMPARE1_LSB_PTR) 
    void    Debounce_WriteCompare2(uint8 compare) ;
    #define Debounce_ReadCompare2() CY_GET_REG8(Debounce_COMPARE2_LSB_PTR) 
#endif


#if (Debounce_DeadBandUsed)
    void    Debounce_WriteDeadTime(uint8 deadtime) ;
    uint8   Debounce_ReadDeadTime(void) ;
#endif

#if ( Debounce_KillModeMinTime)
    #define Debounce_WriteKillTime(killtime) CY_SET_REG8(Debounce_KILLMODEMINTIME_PTR, killtime) 
    #define Debounce_ReadKillTime() CY_GET_REG8(Debounce_KILLMODEMINTIME_PTR) 
#endif

void Debounce_Init(void) ;
void Debounce_Enable(void) ;
void Debounce_Sleep(void);
void Debounce_Wakeup(void) ;
void Debounce_SaveConfig(void);
void Debounce_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define Debounce_INIT_PERIOD_VALUE        24
#define Debounce_INIT_COMPARE_VALUE1      4
#define Debounce_INIT_COMPARE_VALUE2      63
#define Debounce_INIT_INTERRUPTS_MODE     ((0 << Debounce_STATUS_TC_INT_EN_MASK_SHIFT) | (0 << Debounce_STATUS_CMP2_INT_EN_MASK_SHIFT) | (0 << Debounce_STATUS_CMP1_INT_EN_MASK_SHIFT ) | (0 << Debounce_STATUS_KILL_INT_EN_MASK_SHIFT ))
#define Debounce_DEFAULT_COMPARE2_MODE    (1 << Debounce_CTRL_CMPMODE2_SHIFT)
#define Debounce_DEFAULT_COMPARE1_MODE    (1 << Debounce_CTRL_CMPMODE1_SHIFT)
#define Debounce_INIT_DEAD_TIME           1


/********************************
*         Registers
******************************** */

#if (Debounce_UsingFixedFunction)
   #define Debounce_PERIOD_LSB      (*(reg16 *) Debounce_PWMHW__PER0)
   #define Debounce_PERIOD_LSB_PTR   ((reg16 *) Debounce_PWMHW__PER0)
   #define Debounce_COMPARE1_LSB    (*(reg16 *) Debounce_PWMHW__CNT_CMP0)
   #define Debounce_COMPARE1_LSB_PTR ((reg16 *) Debounce_PWMHW__CNT_CMP0)
   #define Debounce_COMPARE2_LSB     0x00u
   #define Debounce_COMPARE2_LSB_PTR 0x00u
   #define Debounce_COUNTER_LSB     (*(reg16 *) Debounce_PWMHW__CNT_CMP0)
   #define Debounce_COUNTER_LSB_PTR  ((reg16 *) Debounce_PWMHW__CNT_CMP0)
   #define Debounce_CAPTURE_LSB     (*(reg16 *) Debounce_PWMHW__CAP0)
   #define Debounce_CAPTURE_LSB_PTR  ((reg16 *) Debounce_PWMHW__CAP0)
   
#else
   #if(Debounce_PWMModeIsCenterAligned)
       #define Debounce_PERIOD_LSB      (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define Debounce_PERIOD_LSB_PTR   ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__D1_REG)
   #else
       #define Debounce_PERIOD_LSB      (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #define Debounce_PERIOD_LSB_PTR   ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__F0_REG)
   #endif
   #define Debounce_COMPARE1_LSB    (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__D0_REG)
   #define Debounce_COMPARE1_LSB_PTR ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__D0_REG)
   #define Debounce_COMPARE2_LSB    (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__D1_REG)
   #define Debounce_COMPARE2_LSB_PTR ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__D1_REG)
   #define Debounce_COUNTERCAP_LSB   *(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define Debounce_COUNTERCAP_LSB_PTR ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define Debounce_COUNTER_LSB     (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__A0_REG)
   #define Debounce_COUNTER_LSB_PTR  ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__A0_REG)
   #define Debounce_CAPTURE_LSB     (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__F1_REG)
   #define Debounce_CAPTURE_LSB_PTR  ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__F1_REG)
   #define Debounce_AUX_CONTROLDP0      (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define Debounce_AUX_CONTROLDP0_PTR  ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #if (Debounce_Resolution == 16)
       #define Debounce_AUX_CONTROLDP1    (*(reg8 *) Debounce_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define Debounce_AUX_CONTROLDP1_PTR  ((reg8 *) Debounce_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
   #endif
#endif
   
#if(Debounce_KillModeMinTime )
    #define Debounce_KILLMODEMINTIME      (*(reg8 *) Debounce_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define Debounce_KILLMODEMINTIME_PTR   ((reg8 *) Debounce_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif

#if(Debounce_DeadBandMode == Debounce__B_PWM__DBM_256_CLOCKS)
    #define Debounce_DEADBAND_COUNT        (*(reg8 *) Debounce_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define Debounce_DEADBAND_COUNT_PTR     ((reg8 *) Debounce_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
#elif(Debounce_DeadBandMode == Debounce__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (Debounce_UsingFixedFunction)
        #define Debounce_DEADBAND_COUNT        (*(reg8 *) Debounce_PWMHW__CFG0) 
        #define Debounce_DEADBAND_COUNT_PTR     ((reg8 *) Debounce_PWMHW__CFG0)
        #define Debounce_DEADBAND_COUNT_MASK    (0x03u << Debounce_DEADBAND_COUNT_SHIFT) 
        #define Debounce_DEADBAND_COUNT_SHIFT   0x06u /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */ 
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define Debounce_DEADBAND_COUNT        (*(reg8 *) Debounce_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Debounce_DEADBAND_COUNT_PTR     ((reg8 *) Debounce_PWMUDB_sDB3_AsyncCtl_dbctrlreg__CONTROL_REG)
        #define Debounce_DEADBAND_COUNT_MASK    (0x03u << Debounce_DEADBAND_COUNT_SHIFT) 
        #define Debounce_DEADBAND_COUNT_SHIFT   0x00u /* As defined by the verilog implementation of the Control Register */
    #endif
#endif



#if (Debounce_UsingFixedFunction)
    #define Debounce_STATUS                (*(reg8 *) Debounce_PWMHW__SR0)
    #define Debounce_STATUS_PTR            ((reg8 *) Debounce_PWMHW__SR0)
    #define Debounce_STATUS_MASK           (*(reg8 *) Debounce_PWMHW__SR0)
    #define Debounce_STATUS_MASK_PTR       ((reg8 *) Debounce_PWMHW__SR0)
    #define Debounce_CONTROL               (*(reg8 *) Debounce_PWMHW__CFG0)
    #define Debounce_CONTROL_PTR           ((reg8 *) Debounce_PWMHW__CFG0)    
    #define Debounce_CONTROL2              (*(reg8 *) Debounce_PWMHW__CFG1)    
    #if(Debounce_PSOC3_ES3 || Debounce_PSOC5_ES2)
        #define Debounce_CONTROL3              (*(reg8 *) Debounce_PWMHW__CFG2)
    #endif
    #define Debounce_GLOBAL_ENABLE         (*(reg8 *) Debounce_PWMHW__PM_ACT_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/
    /* Fixed Function Block Chosen */
    #define Debounce_BLOCK_EN_MASK          Debounce_PWMHW__PM_ACT_MSK
    /* Control Register definitions */
    #define Debounce_CTRL_ENABLE_SHIFT      0x00u
    
    #if(Debounce_PSOC3_ES2 || Debounce_PSOC5_ES1)
        #define Debounce_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif
    #if(Debounce_PSOC3_ES3 || Debounce_PSOC5_ES2)
        #define Debounce_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif
    
    #define Debounce_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define Debounce_CFG0_MODE              0x02u   /*  Set to compare mode */
    //#define Debounce_CFG0_ENABLE            0x01u   /* Enable the block to run */
    #define Debounce_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define Debounce_CTRL_ENABLE            (0x01u << Debounce_CTRL_ENABLE_SHIFT)
    #define Debounce_CTRL_RESET             (0x01u << Debounce_CTRL_RESET_SHIFT)
    #define Debounce_CTRL_CMPMODE2_MASK     (0x07u << Debounce_CTRL_CMPMODE2_SHIFT)
    #if(Debounce_PSOC3_ES2 || Debounce_PSOC5_ES1)
        #define Debounce_CTRL_CMPMODE1_MASK     (0x07u << Debounce_CTRL_CMPMODE1_SHIFT)
    #endif
    #if(Debounce_PSOC3_ES3 || Debounce_PSOC5_ES2)
        #define Debounce_CTRL_CMPMODE1_MASK     (0x07u << Debounce_CTRL_CMPMODE1_SHIFT)
    #endif
    
    /* Control2 Register Bit Masks */
    #define Debounce_CTRL2_IRQ_SEL_SHIFT    0x00u       /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define Debounce_CTRL2_IRQ_SEL          (0x01u << Debounce_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define Debounce_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define Debounce_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define Debounce_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define Debounce_STATUS_TC_INT_EN_MASK_SHIFT            (Debounce_STATUS_TC_SHIFT - 4)
    #define Debounce_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define Debounce_STATUS_CMP1_INT_EN_MASK_SHIFT          (Debounce_STATUS_CMP1_SHIFT - 4)
    
    /* Status Register Bit Masks */
    #define Debounce_STATUS_TC              (0x01u << Debounce_STATUS_TC_SHIFT)
    #define Debounce_STATUS_CMP1            (0x01u << Debounce_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define Debounce_STATUS_TC_INT_EN_MASK              (Debounce_STATUS_TC >> 4)
    #define Debounce_STATUS_CMP1_INT_EN_MASK            (Debounce_STATUS_CMP1 >> 4)

#else
    #define Debounce_STATUS                (*(reg8 *) Debounce_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Debounce_STATUS_PTR            ((reg8 *) Debounce_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define Debounce_STATUS_MASK           (*(reg8 *) Debounce_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Debounce_STATUS_MASK_PTR       ((reg8 *) Debounce_PWMUDB_sSTSReg_nrstSts_stsreg__MASK_REG)
    #define Debounce_STATUS_AUX_CTRL       (*(reg8 *) Debounce_PWMUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define Debounce_CONTROL               (*(reg8 *) Debounce_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    #define Debounce_CONTROL_PTR           ((reg8 *) Debounce_PWMUDB_sCTRLReg_AsyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/
    /* Control Register definitions */
    #define Debounce_CTRL_ENABLE_SHIFT      0x07u
    #define Debounce_CTRL_RESET_SHIFT       0x06u
    #define Debounce_CTRL_CMPMODE2_SHIFT    0x03u
    #define Debounce_CTRL_CMPMODE1_SHIFT    0x00u
    #define Debounce_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define Debounce_CTRL_ENABLE            (0x01u << Debounce_CTRL_ENABLE_SHIFT)
    #define Debounce_CTRL_RESET             (0x01u << Debounce_CTRL_RESET_SHIFT)
    #define Debounce_CTRL_CMPMODE2_MASK     (0x07u << Debounce_CTRL_CMPMODE2_SHIFT)
    #define Debounce_CTRL_CMPMODE1_MASK     (0x07u << Debounce_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define Debounce_STATUS_KILL_SHIFT          0x05u
    #define Debounce_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define Debounce_STATUS_FIFOFULL_SHIFT      0x03u  
    #define Debounce_STATUS_TC_SHIFT            0x02u
    #define Debounce_STATUS_CMP2_SHIFT          0x01u
    #define Debounce_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define Debounce_STATUS_KILL_INT_EN_MASK_SHIFT          Debounce_STATUS_KILL_SHIFT          
    #define Debounce_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    Debounce_STATUS_FIFONEMPTY_SHIFT    
    #define Debounce_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      Debounce_STATUS_FIFOFULL_SHIFT        
    #define Debounce_STATUS_TC_INT_EN_MASK_SHIFT            Debounce_STATUS_TC_SHIFT            
    #define Debounce_STATUS_CMP2_INT_EN_MASK_SHIFT          Debounce_STATUS_CMP2_SHIFT          
    #define Debounce_STATUS_CMP1_INT_EN_MASK_SHIFT          Debounce_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define Debounce_STATUS_KILL            (0x00u << Debounce_STATUS_KILL_SHIFT )
    #define Debounce_STATUS_FIFOFULL        (0x01u << Debounce_STATUS_FIFOFULL_SHIFT)
    #define Debounce_STATUS_FIFONEMPTY      (0x01u << Debounce_STATUS_FIFONEMPTY_SHIFT)
    #define Debounce_STATUS_TC              (0x01u << Debounce_STATUS_TC_SHIFT)
    #define Debounce_STATUS_CMP2            (0x01u << Debounce_STATUS_CMP2_SHIFT) 
    #define Debounce_STATUS_CMP1            (0x01u << Debounce_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define Debounce_STATUS_KILL_INT_EN_MASK            Debounce_STATUS_KILL
    #define Debounce_STATUS_FIFOFULL_INT_EN_MASK        Debounce_STATUS_FIFOFULL
    #define Debounce_STATUS_FIFONEMPTY_INT_EN_MASK      Debounce_STATUS_FIFONEMPTY
    #define Debounce_STATUS_TC_INT_EN_MASK              Debounce_STATUS_TC
    #define Debounce_STATUS_CMP2_INT_EN_MASK            Debounce_STATUS_CMP2
    #define Debounce_STATUS_CMP1_INT_EN_MASK            Debounce_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define Debounce_AUX_CTRL_FIFO0_CLR     0x01u
    #define Debounce_AUX_CTRL_FIFO1_CLR     0x02u
    #define Debounce_AUX_CTRL_FIFO0_LVL     0x04u
    #define Debounce_AUX_CTRL_FIFO1_LVL     0x08u
    #define Debounce_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* Debounce_UsingFixedFunction */

#endif  /* CY_PWM_Debounce_H */
