/*******************************************************************************
* File Name: FCounter.h  
* Version 1.50
*
*  Description:
*   Contains the function prototypes and constants available to the counter
*   user module.
*
*   Note:
*    None
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/
    
#if !defined(CY_COUNTER_FCounter_H)
#define CY_COUNTER_FCounter_H

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define FCounter_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES1 or early */
#define FCounter_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define FCounter_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES2 or later */
#define FCounter_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))


/**************************************
*           Parameter Defaults        
**************************************/

#define FCounter_Resolution            32u
#define FCounter_UsingFixedFunction    0u
#define FCounter_ControlRegRemoved     1u
#define FCounter_COMPARE_MODE_SOFTWARE 0u
#define FCounter_CAPTURE_MODE_SOFTWARE 0u
#define FCounter_RunModeUsed           0u


/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct FCounter_backupStruct
{
    #if (!FCounter_ControlRegRemoved)
        #if (!FCounter_UsingFixedFunction)
            uint8 control;
        #endif
        
        uint8 enableState;
    #endif   
    
    #if (!FCounter_UsingFixedFunction)
        uint32 counterUdb;
        uint32 captureValue;
    #endif
}FCounter_backupStruct;


/**************************************
 *  Function Prototypes
 *************************************/
void    FCounter_Start(void);
void    FCounter_Stop(void) ;
void    FCounter_SetInterruptMode(uint8 interruptsMask) ;
uint8   FCounter_GetInterruptSource(void) ;
uint8   FCounter_ReadStatusRegister(void) ;
#if(!FCounter_ControlRegRemoved)
    uint8   FCounter_ReadControlRegister(void) ;
    void    FCounter_WriteControlRegister(uint8 control) \
        ;
#endif
void    FCounter_WriteCounter(uint32 counter) \
    ; 
uint32  FCounter_ReadCounter(void) ;
uint32  FCounter_ReadCapture(void) ;
void    FCounter_WritePeriod(uint32 period) \
    ;
uint32  FCounter_ReadPeriod( void ) ;
#if (!FCounter_UsingFixedFunction)
    void    FCounter_WriteCompare(uint32 compare) \
        ;
    uint32  FCounter_ReadCompare( void ) \
        ;
#endif

#if (FCounter_COMPARE_MODE_SOFTWARE)
    void    FCounter_SetCompareMode(uint8 comparemode) ;
#endif
#if (FCounter_CAPTURE_MODE_SOFTWARE)
    void    FCounter_SetCaptureMode(uint8 capturemode) ;
#endif
void FCounter_ClearFIFO(void)     ;
void FCounter_Init(void)          ;
void FCounter_Enable(void)        ;
void FCounter_SaveConfig(void)    ;
void FCounter_RestoreConfig(void) ;
void FCounter_Sleep(void)         ;
void FCounter_Wakeup(void)        ;

/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Counter__CompareModes, Used in Compare Mode */
#define FCounter__B_COUNTER__LESS_THAN 1
#define FCounter__B_COUNTER__LESS_THAN_OR_EQUAL 2
#define FCounter__B_COUNTER__EQUAL 0
#define FCounter__B_COUNTER__GREATER_THAN 3
#define FCounter__B_COUNTER__GREATER_THAN_OR_EQUAL 4
#define FCounter__B_COUNTER__SOFTWARE 5


/* Enumerated Type B_Counter__CaptureModes, Used in Capture Mode */
#define FCounter__B_COUNTER__NONE 0
#define FCounter__B_COUNTER__RISING_EDGE 1
#define FCounter__B_COUNTER__FALLING_EDGE 2
#define FCounter__B_COUNTER__EITHER_EDGE 3
#define FCounter__B_COUNTER__SOFTWARE_CONTROL 4


/***************************************
 *  Initialization Values
 **************************************/
#define FCounter_INIT_PERIOD_VALUE       4294967295u
#define FCounter_INIT_COUNTER_VALUE      0u
#if (FCounter_UsingFixedFunction)
#define FCounter_INIT_INTERRUPTS_MASK    ((0u << FCounter_STATUS_ZERO_INT_EN_MASK_SHIFT))
#else
#define FCounter_INIT_COMPARE_VALUE      128u
#define FCounter_INIT_INTERRUPTS_MASK ((0u << FCounter_STATUS_ZERO_INT_EN_MASK_SHIFT) | \
        (0u << FCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT) | \
        (0u << FCounter_STATUS_CMP_INT_EN_MASK_SHIFT) | \
        (0u << FCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT) | \
        (0u << FCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT))
#define FCounter_DEFAULT_COMPARE_MODE    (1u << FCounter_CTRL_CMPMODE0_SHIFT)
#define FCounter_DEFAULT_CAPTURE_MODE    (0u << FCounter_CTRL_CAPMODE0_SHIFT)
#endif /* (FCounter_UsingFixedFunction) */

/**************************************
 *  Registers
 *************************************/
#if (FCounter_UsingFixedFunction)
    #define FCounter_STATICCOUNT_LSB     (*(reg16 *) FCounter_CounterHW__CAP0 )
    #define FCounter_STATICCOUNT_LSB_PTR ( (reg16 *) FCounter_CounterHW__CAP0 )
    #define FCounter_PERIOD_LSB          (*(reg16 *) FCounter_CounterHW__PER0 )
    #define FCounter_PERIOD_LSB_PTR      ( (reg16 *) FCounter_CounterHW__PER0 )
    /* MODE must be set to 1 to set the compare value */
    #define FCounter_COMPARE_LSB         (*(reg16 *) FCounter_CounterHW__CNT_CMP0 )
    #define FCounter_COMPARE_LSB_PTR     ( (reg16 *) FCounter_CounterHW__CNT_CMP0 )
    /* MODE must be set to 0 to get the count */
    #define FCounter_COUNTER_LSB         (*(reg16 *) FCounter_CounterHW__CNT_CMP0 )
    #define FCounter_COUNTER_LSB_PTR     ( (reg16 *) FCounter_CounterHW__CNT_CMP0 )
#else
    #define FCounter_STATICCOUNT_LSB     (*(reg32 *) \
        FCounter_CounterUDB_sC32_counterdp_u0__F0_REG )
    #define FCounter_STATICCOUNT_LSB_PTR ( (reg32 *) \
        FCounter_CounterUDB_sC32_counterdp_u0__F0_REG )
    #define FCounter_PERIOD_LSB          (*(reg32 *) \
        FCounter_CounterUDB_sC32_counterdp_u0__D0_REG )
    #define FCounter_PERIOD_LSB_PTR      ( (reg32 *) \
        FCounter_CounterUDB_sC32_counterdp_u0__D0_REG )
    #define FCounter_COMPARE_LSB         (*(reg32 *) \
        FCounter_CounterUDB_sC32_counterdp_u0__D1_REG )
    #define FCounter_COMPARE_LSB_PTR     ( (reg32 *) \
        FCounter_CounterUDB_sC32_counterdp_u0__D1_REG )
    #define FCounter_COUNTER_LSB         (*(reg32 *) \
        FCounter_CounterUDB_sC32_counterdp_u0__A0_REG )
    #define FCounter_COUNTER_LSB_PTR     ( (reg32 *)\
        FCounter_CounterUDB_sC32_counterdp_u0__A0_REG )

	#define FCounter_AUX_CONTROLDP0 \
        (*(reg8 *) FCounter_CounterUDB_sC32_counterdp_u0__DP_AUX_CTL_REG)
    #define FCounter_AUX_CONTROLDP0_PTR \
        ( (reg8 *) FCounter_CounterUDB_sC32_counterdp_u0__DP_AUX_CTL_REG)
    #if (FCounter_Resolution == 16 || FCounter_Resolution == 24 || FCounter_Resolution == 32)
       #define FCounter_AUX_CONTROLDP1 \
           (*(reg8 *) FCounter_CounterUDB_sC32_counterdp_u1__DP_AUX_CTL_REG)
       #define FCounter_AUX_CONTROLDP1_PTR \
           ( (reg8 *) FCounter_CounterUDB_sC32_counterdp_u1__DP_AUX_CTL_REG)
    #endif
    #if (FCounter_Resolution == 24 || FCounter_Resolution == 32)
       #define FCounter_AUX_CONTROLDP2 \
           (*(reg8 *) FCounter_CounterUDB_sC32_counterdp_u2__DP_AUX_CTL_REG)
       #define FCounter_AUX_CONTROLDP2_PTR \
           ( (reg8 *) FCounter_CounterUDB_sC32_counterdp_u2__DP_AUX_CTL_REG)
    #endif
    #if (FCounter_Resolution == 32)
       #define FCounter_AUX_CONTROLDP3 \
           (*(reg8 *) FCounter_CounterUDB_sC32_counterdp_u3__DP_AUX_CTL_REG)
       #define FCounter_AUX_CONTROLDP3_PTR \
           ( (reg8 *) FCounter_CounterUDB_sC32_counterdp_u3__DP_AUX_CTL_REG)
    #endif
#endif  /* (FCounter_UsingFixedFunction) */

#if (FCounter_UsingFixedFunction)
    #define FCounter_STATUS         (*(reg8 *) FCounter_CounterHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define FCounter_STATUS_MASK             (*(reg8 *) FCounter_CounterHW__SR0 )
    #define FCounter_STATUS_MASK_PTR         ( (reg8 *) FCounter_CounterHW__SR0 )
    #define FCounter_CONTROL                 (*(reg8 *) FCounter_CounterHW__CFG0)
    #define FCounter_CONTROL_PTR             ( (reg8 *) FCounter_CounterHW__CFG0)
    #define FCounter_CONTROL2                (*(reg8 *) FCounter_CounterHW__CFG1)
    #define FCounter_CONTROL2_PTR            ( (reg8 *) FCounter_CounterHW__CFG1)
    #if (FCounter_PSOC3_ES3 || FCounter_PSOC5_ES2)
        #define FCounter_CONTROL3       (*(reg8 *) FCounter_CounterHW__CFG2)
        #define FCounter_CONTROL3_PTR   ( (reg8 *) FCounter_CounterHW__CFG2)
    #endif
    #define FCounter_GLOBAL_ENABLE           (*(reg8 *) FCounter_CounterHW__PM_ACT_CFG)
    #define FCounter_GLOBAL_ENABLE_PTR       ( (reg8 *) FCounter_CounterHW__PM_ACT_CFG)
    #define FCounter_GLOBAL_STBY_ENABLE      (*(reg8 *) FCounter_CounterHW__PM_STBY_CFG)
    #define FCounter_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) FCounter_CounterHW__PM_STBY_CFG)
    
    /********************************
    *    Constants
    ********************************/
    /* Fixed Function Block Chosen */
    #define FCounter_BLOCK_EN_MASK          FCounter_CounterHW__PM_ACT_MSK
    #define FCounter_BLOCK_STBY_EN_MASK     FCounter_CounterHW__PM_STBY_MSK 
    
    /* Control Register Bit Locations */    
    /* As defined in Register Map, part of TMRX_CFG0 register */
    #define FCounter_CTRL_ENABLE_SHIFT      0x00u
    /* Control Register Bit Masks */
    #define FCounter_CTRL_ENABLE            (0x01u << FCounter_CTRL_ENABLE_SHIFT)         

    /* Control2 Register Bit Masks */
    /* Set the mask for run mode */
    #if (FCounter_PSOC3_ES2 || FCounter_PSOC5_ES1)
        /* Use CFG1 Mode bits to set run mode */
        #define FCounter_CTRL_MODE_SHIFT        0x01u    
        #define FCounter_CTRL_MODE_MASK         (0x07u << FCounter_CTRL_MODE_SHIFT)
    #endif
    #if (FCounter_PSOC3_ES3 || FCounter_PSOC5_ES2)
        /* Use CFG2 Mode bits to set run mode */
        #define FCounter_CTRL_MODE_SHIFT        0x00u    
        #define FCounter_CTRL_MODE_MASK         (0x03u << FCounter_CTRL_MODE_SHIFT)
    #endif
    /* Set the mask for interrupt (raw/status register) */
    #define FCounter_CTRL2_IRQ_SEL_SHIFT     0x00u
    #define FCounter_CTRL2_IRQ_SEL          (0x01u << FCounter_CTRL2_IRQ_SEL_SHIFT)     
    
    /* Status Register Bit Locations */
    #define FCounter_STATUS_ZERO_SHIFT      0x07u  /* As defined in Register Map, part of TMRX_SR0 register */ 

    /* Status Register Interrupt Enable Bit Locations */
    #define FCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      (FCounter_STATUS_ZERO_SHIFT - 0x04u)

    /* Status Register Bit Masks */                           
    #define FCounter_STATUS_ZERO            (0x01u << FCounter_STATUS_ZERO_SHIFT)

    /* Status Register Interrupt Bit Masks*/
    #define FCounter_STATUS_ZERO_INT_EN_MASK       (FCounter_STATUS_ZERO >> 0x04u)

#else /* !FCounter_UsingFixedFunction */
    #define FCounter_STATUS               (* (reg8 *) FCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define FCounter_STATUS_PTR           (  (reg8 *) FCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_REG )
    #define FCounter_STATUS_MASK          (* (reg8 *) FCounter_CounterUDB_sSTSReg_nrstSts_stsreg__MASK_REG )
    #define FCounter_STATUS_MASK_PTR      (  (reg8 *) FCounter_CounterUDB_sSTSReg_nrstSts_stsreg__MASK_REG )
    #define FCounter_STATUS_AUX_CTRL      (*(reg8 *) FCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define FCounter_STATUS_AUX_CTRL_PTR  ( (reg8 *) FCounter_CounterUDB_sSTSReg_nrstSts_stsreg__STATUS_AUX_CTL_REG)
    #define FCounter_CONTROL              (* (reg8 *) FCounter_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )
    #define FCounter_CONTROL_PTR          (  (reg8 *) FCounter_CounterUDB_sCTRLReg_ctrlreg__CONTROL_REG )

    /********************************
    *    Constants
    ********************************/
    /* Control Register Bit Locations */
    #define FCounter_CTRL_CMPMODE0_SHIFT    0x00u       /* As defined by Verilog Implementation */
    #define FCounter_CTRL_CAPMODE0_SHIFT    0x03u       /* As defined by Verilog Implementation */
    #define FCounter_CTRL_RESET_SHIFT       0x06u       /* As defined by Verilog Implementation */
    #define FCounter_CTRL_ENABLE_SHIFT      0x07u       /* As defined by Verilog Implementation */
    /* Control Register Bit Masks */
    #define FCounter_CTRL_CMPMODE_MASK      (0x07u << FCounter_CTRL_CMPMODE0_SHIFT)  
    #define FCounter_CTRL_CAPMODE_MASK      (0x03u << FCounter_CTRL_CAPMODE0_SHIFT)  
    #define FCounter_CTRL_RESET             (0x01u << FCounter_CTRL_RESET_SHIFT)  
    #define FCounter_CTRL_ENABLE            (0x01u << FCounter_CTRL_ENABLE_SHIFT) 

    /* Status Register Bit Locations */
    #define FCounter_STATUS_CMP_SHIFT       0x00u       /* As defined by Verilog Implementation */
    #define FCounter_STATUS_ZERO_SHIFT      0x01u       /* As defined by Verilog Implementation */
    #define FCounter_STATUS_OVERFLOW_SHIFT  0x02u       /* As defined by Verilog Implementation */
    #define FCounter_STATUS_UNDERFLOW_SHIFT 0x03u       /* As defined by Verilog Implementation */
    #define FCounter_STATUS_CAPTURE_SHIFT   0x04u       /* As defined by Verilog Implementation */
    #define FCounter_STATUS_FIFOFULL_SHIFT  0x05u       /* As defined by Verilog Implementation */
    #define FCounter_STATUS_FIFONEMP_SHIFT  0x06u       /* As defined by Verilog Implementation */
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define FCounter_STATUS_CMP_INT_EN_MASK_SHIFT       FCounter_STATUS_CMP_SHIFT       
    #define FCounter_STATUS_ZERO_INT_EN_MASK_SHIFT      FCounter_STATUS_ZERO_SHIFT      
    #define FCounter_STATUS_OVERFLOW_INT_EN_MASK_SHIFT  FCounter_STATUS_OVERFLOW_SHIFT  
    #define FCounter_STATUS_UNDERFLOW_INT_EN_MASK_SHIFT FCounter_STATUS_UNDERFLOW_SHIFT 
    #define FCounter_STATUS_CAPTURE_INT_EN_MASK_SHIFT   FCounter_STATUS_CAPTURE_SHIFT   
    #define FCounter_STATUS_FIFOFULL_INT_EN_MASK_SHIFT  FCounter_STATUS_FIFOFULL_SHIFT  
    #define FCounter_STATUS_FIFONEMP_INT_EN_MASK_SHIFT  FCounter_STATUS_FIFONEMP_SHIFT  
    /* Status Register Bit Masks */                
    #define FCounter_STATUS_CMP             (0x01u << FCounter_STATUS_CMP_SHIFT)  
    #define FCounter_STATUS_ZERO            (0x01u << FCounter_STATUS_ZERO_SHIFT) 
    #define FCounter_STATUS_OVERFLOW        (0x01u << FCounter_STATUS_OVERFLOW_SHIFT) 
    #define FCounter_STATUS_UNDERFLOW       (0x01u << FCounter_STATUS_UNDERFLOW_SHIFT) 
    #define FCounter_STATUS_CAPTURE         (0x01u << FCounter_STATUS_CAPTURE_SHIFT) 
    #define FCounter_STATUS_FIFOFULL        (0x01u << FCounter_STATUS_FIFOFULL_SHIFT)
    #define FCounter_STATUS_FIFONEMP        (0x01u << FCounter_STATUS_FIFONEMP_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define FCounter_STATUS_CMP_INT_EN_MASK            FCounter_STATUS_CMP                    
    #define FCounter_STATUS_ZERO_INT_EN_MASK           FCounter_STATUS_ZERO            
    #define FCounter_STATUS_OVERFLOW_INT_EN_MASK       FCounter_STATUS_OVERFLOW        
    #define FCounter_STATUS_UNDERFLOW_INT_EN_MASK      FCounter_STATUS_UNDERFLOW       
    #define FCounter_STATUS_CAPTURE_INT_EN_MASK        FCounter_STATUS_CAPTURE         
    #define FCounter_STATUS_FIFOFULL_INT_EN_MASK       FCounter_STATUS_FIFOFULL        
    #define FCounter_STATUS_FIFONEMP_INT_EN_MASK       FCounter_STATUS_FIFONEMP         
    

    /* StatusI Interrupt Enable bit Location in the Auxilliary Control Register */
    #define FCounter_STATUS_ACTL_INT_EN     0x10u /* As defined for the ACTL Register */
    
    /* Datapath Auxillary Control Register definitions */
    #define FCounter_AUX_CTRL_FIFO0_CLR         0x01u   /* As defined by Register map */
    #define FCounter_AUX_CTRL_FIFO1_CLR         0x02u   /* As defined by Register map */
    #define FCounter_AUX_CTRL_FIFO0_LVL         0x04u   /* As defined by Register map */
    #define FCounter_AUX_CTRL_FIFO1_LVL         0x08u   /* As defined by Register map */
    #define FCounter_STATUS_ACTL_INT_EN_MASK    0x10u   /* As defined for the ACTL Register */
    
#endif /* FCounter_UsingFixedFunction */

#endif  /* CY_COUNTER_FCounter_H */


/* [] END OF FILE */

