/*******************************************************************************
* File Name: Mixer_L.h  
* Version 1.50
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Mixer component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_MIXER_Mixer_L_H) 
#define CY_MIXER_Mixer_L_H 

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
* Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define Mixer_L_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES1 or early */
#define Mixer_L_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define Mixer_L_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))
/* PSoC5 ES2 or later */
#define Mixer_L_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))


/***************************************
*   Data Struct Definition
***************************************/

/* Low power Mode API Support */
typedef struct _Mixer_L_backupStruct
{
    uint8   enableState;
}   Mixer_L_BACKUP_STRUCT;


/***************************************
*        Function Prototypes 
***************************************/

void Mixer_L_Start(void);
void Mixer_L_Stop(void) ;
void Mixer_L_SetPower(uint8 power) ;
void Mixer_L_Sleep(void);
void Mixer_L_Wakeup(void) ;
void Mixer_L_SaveConfig(void);
void Mixer_L_RestoreConfig(void);
void Mixer_L_Init(void) ;
void Mixer_L_Enable(void) ;


/***************************************
*              Constants        
***************************************/

/* Constants for Mixer Type */
#define Mixer_L_CTMIXER                (0x00u)
#define Mixer_L_DTMIXER                (0x01u)

/* Constants for Local Oscillator Freq */
#define Mixer_L_LO_LT_100K             (0x00u)
#define Mixer_L_LO_GTE_100K            (0x01u)

/* Constants for Minimum Vdda paramater */
#define  Mixer_L_MIN_VDDA_GTE_2_7V     (0x00u)
#define  Mixer_L_MIN_VDDA_LT_2_7V      (0x01u)

/* Constants for SetPower function */
#define Mixer_L_MINPOWER               (0x00u)
#define Mixer_L_LOWPOWER               (0x01u)
#define Mixer_L_MEDPOWER               (0x02u)
#define Mixer_L_HIGHPOWER              (0x03u)

/* Constant for VDDA Threshold */
#define Mixer_L_CYDEV_VDDA_MV          (CYDEV_VDDA_MV)
#define Mixer_L_VDDA_THRESHOLD_MV      (3500u)


/***************************************
*       Initial Paramater Values
***************************************/

#define Mixer_L_MIXER_TYPE             (1u)
#define Mixer_L_INIT_POWER             (3u)
#define Mixer_L_LO_FREQ_FLAG           (1u)
#define Mixer_L_MIN_VDDA               (0u)


/***************************************
*              Registers        
***************************************/

/* SC Block Configuration Registers */
#define Mixer_L_CR0_REG                (* (reg8 *) Mixer_L_SC__CR0 )
#define Mixer_L_CR0_PTR                (  (reg8 *) Mixer_L_SC__CR0 )
#define Mixer_L_CR1_REG                (* (reg8 *) Mixer_L_SC__CR1 )
#define Mixer_L_CR1_PTR                (  (reg8 *) Mixer_L_SC__CR1 )
#define Mixer_L_CR2_REG                (* (reg8 *) Mixer_L_SC__CR2 )
#define Mixer_L_CR2_PTR                (  (reg8 *) Mixer_L_SC__CR2 )
#define Mixer_L_CLK_REG                (* (reg8 *) Mixer_L_SC__CLK )  /* SC Block clk control */
#define Mixer_L_CLK_PTR                (  (reg8 *) Mixer_L_SC__CLK )
#define Mixer_L_BSTCLK_REG             (* (reg8 *) Mixer_L_SC__BST )  /* SC Boost clk Control */
#define Mixer_L_BSTCLK_PTR             (  (reg8 *) Mixer_L_SC__BST )
#define Mixer_L_PM_ACT_CFG_REG         (* (reg8 *) Mixer_L_SC__PM_ACT_CFG )  /* Power manager */
#define Mixer_L_PM_ACT_CFG_PTR         (  (reg8 *) Mixer_L_SC__PM_ACT_CFG )
#define Mixer_L_PM_STBY_CFG_REG        (* (reg8 *) Mixer_L_SC__PM_STBY_CFG )  /* Power manager */
#define Mixer_L_PM_STBY_CFG_PTR        (  (reg8 *) Mixer_L_SC__PM_STBY_CFG )

/* Pump clock selectin register */
#define Mixer_L_PUMP_CR1_REG           (* (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)   
#define Mixer_L_PUMP_CR1_PTR           (  (reg8 *) CYDEV_ANAIF_CFG_PUMP_CR1)

/* Pump Register for SC block */
#define Mixer_L_SC_MISC_REG            (* (reg8 *) CYDEV_ANAIF_RT_SC_MISC)
#define Mixer_L_SC_MISC_PTR            (  (reg8 *) CYDEV_ANAIF_RT_SC_MISC)

/* PM_ACT_CFG (Active Power Mode CFG Register) mask */ 
#define Mixer_L_ACT_PWR_EN             Mixer_L_SC__PM_ACT_MSK /* Power enable mask */

/* PM_STBY_CFG (Alternative Active Power Mode CFG Register) mask */ 
#define Mixer_L_STBY_PWR_EN             Mixer_L_SC__PM_STBY_MSK /* Power enable mask */



/***************************************
*        Register Constants        
***************************************/

/* ANIF.PUMP.CR1 Constants */
#define Mixer_L_PUMP_CR1_SC_CLKSEL     (0x80u)

/* SC_MISC constants */
#define Mixer_L_PUMP_FORCE             (0x20u)
#define Mixer_L_PUMP_AUTO              (0x10u)
#define Mixer_L_DIFF_PGA_1_3           (0x02u)
#define Mixer_L_DIFF_PGA_0_2           (0x01u)

/* CR0 SC Block Control Register 0 definitions */

/* Bit Field SC_MODE_ENUM - SCxx_CR0[3:1] */
#define Mixer_L_MODE_CTMIXER           (0x02u << 1)
#define Mixer_L_MODE_DTMIXER           (0x03u << 1)

/* CR1 SC Block Control Register 1 definitions */

/* Bit Field  SC_DRIVE_ENUM - SCxx_CR1[1:0] */
#define Mixer_L_DRIVE_MASK             (0x03u)
#define Mixer_L_DRIVE_280UA            (0x00u)
#define Mixer_L_DRIVE_420UA            (0x01u)
#define Mixer_L_DRIVE_530UA            (0x02u)
#define Mixer_L_DRIVE_650UA            (0x03u)

/* Bit Field  SC_COMP_ENUM - SCxx_CR1[3:2] */
#define Mixer_L_COMP_MASK              (0x03u << 2)
#define Mixer_L_COMP_3P0PF             (0x00u << 2)
#define Mixer_L_COMP_3P6PF             (0x01u << 2)
#define Mixer_L_COMP_4P35PF            (0x02u << 2)
#define Mixer_L_COMP_5P1PF             (0x03u << 2)

/* Bit Field  SC_DIV2_ENUM - SCxx_CR1[4] */
#define Mixer_L_DIV2                   (0x01u << 4)
#define Mixer_L_DIV2_DISABLE           (0x00u << 4)
#define Mixer_L_DIV2_ENABLE            (0x01u << 4)

/* Bit Field  SC_GAIN_ENUM - SCxx_CR1[5] */
#define Mixer_L_GAIN                    (0x01u << 5)
#define Mixer_L_GAIN_0DB                (0x00u << 5)
#define Mixer_L_GAIN_6DB                (0x01u << 5)

/* CR2 SC Block Control Register 2 definitions */

/* Bit Field  SC_BIAS_CONTROL_ENUM - SCxx_CR2[0] */
#define Mixer_L_BIAS                    (0x01u)
#define Mixer_L_BIAS_NORMAL             (0x00u)
#define Mixer_L_BIAS_LOW                (0x01u)

/* Bit Field  SC_R20_40B_ENUM - SCxx_CR2[1] */
#define Mixer_L_R20_40B                 (0x01u << 1)
#define Mixer_L_R20_40B_40K             (0x00u << 1)
#define Mixer_L_R20_40B_20K             (0x01u << 1)

/* Bit Field  SC_REDC_ENUM  - SCxx_CR2[3:2] */
#define Mixer_L_REDC_MASK               (0x03u << 2)
#define Mixer_L_REDC_00                 (0x00u << 2)
#define Mixer_L_REDC_01                 (0x01u << 2)
#define Mixer_L_REDC_10                 (0x02u << 2)
#define Mixer_L_REDC_11                 (0x03u << 2)

/* Bit Field  SC_RVAL_ENUM  - SCxx_CR2[6:4] */
#define Mixer_L_RVAL_MASK               (0x07u << 4)
#define Mixer_L_RVAL_20K                (0x00u << 4)
#define Mixer_L_RVAL_30K                (0x01u << 4)
#define Mixer_L_RVAL_40K                (0x02u << 4)
#define Mixer_L_RVAL_80K                (0x03u << 4)
#define Mixer_L_RVAL_120K               (0x04u << 4)
#define Mixer_L_RVAL_250K               (0x05u << 4)
#define Mixer_L_RVAL_500K               (0x06u << 4)
#define Mixer_L_RVAL_1000K              (0x07u << 4)

/* Bit Field  SC_PGA_GNDVREF_ENUM - SCxx_CR2[7] */
#define Mixer_L_GNDVREF                 (0x01u << 7)
#define Mixer_L_GNDVREF_DI              (0x00u << 7)
#define Mixer_L_GNDVREF_E               (0x01u << 7) 

/* SC Block Clock Control SCx.CLk */
#define Mixer_L_DYN_CNTL_EN             (0x01u << 5)
#define Mixer_L_BYPASS_SYNC             (0x01u << 4)
#define Mixer_L_CLK_EN                  (0x01u << 3)

/* SC Block Boost Clock Selection Register - Boost Clock Enable  SCxx_BST[3]  */
#define Mixer_L_BST_CLK_EN              (0x01u << 3)

#endif /* CY_MIXER_Mixer_L_H */


/* [] END OF FILE */
