/*******************************************************************************
* File Name: Mixer_R_PM.c  
* Version 1.50
*
* Description:
*  This file provides the power manager source code to the API for 
*  the MIXER component.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "Mixer_R.h"

static Mixer_R_BACKUP_STRUCT  Mixer_R_backup;


/*******************************************************************************
* Function Name: Mixer_R_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*  
* Parameters:  
*  void.
*
* Return: 
*  void.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_R_SaveConfig(void)
{
    /* Nothing to save before entering into sleep mode as all the registers used 
       here are retension registers. */
}


/*******************************************************************************
* Function Name: Mixer_R_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void.
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_R_RestoreConfig(void)
{
    /* Nothing to restore */
}


/*******************************************************************************
* Function Name: Mixer_R_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  Mixer_R_backup:  The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_R_Sleep(void)
{
    /* Save TIA enable state */
    if(Mixer_R_ACT_PWR_EN == (Mixer_R_PM_ACT_CFG_REG & Mixer_R_ACT_PWR_EN))
    {
        /* Component is enabled */
        Mixer_R_backup.enableState = 1u;
    }
    else
    {
        /* Component is disabled */
        Mixer_R_backup.enableState = 0u;
    }

    /* Stop the configuration */
    Mixer_R_Stop();

    /* Saves the user configuration */
    Mixer_R_SaveConfig();
}


/*******************************************************************************
* Function Name: Mixer_R_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  void
*
* Global variables:
*  Mixer_R_backup:  The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void Mixer_R_Wakeup(void) 
{
    /* Restore the user configuration */
    Mixer_R_RestoreConfig();
    
    /* Enable's the component operation */
    if(Mixer_R_backup.enableState == 1u)
    {
        Mixer_R_Enable();
    } /* Do nothing if component was disable before */
}


/* [] END OF FILE */
